@@ -13,9 +13,11 @@ log = logging.getLogger("root")
 
 def parse_args(args):
     # Create argument parser
-    formatter_class = lambda prog: argparse.HelpFormatter(  # noqa: E731
-        prog, max_help_position=100, width=200
-    )
+    def formatter_class(prog):
+        return argparse.HelpFormatter(  # noqa: E731
+            prog, max_help_position=100, width=200
+        )
+
     parser = argparse.ArgumentParser(
         prog="copyrightmgr", formatter_class=formatter_class
     )
@@ -104,5 +106,5 @@ def handle_input_dir(args):
 
 def read_config(config_file):
     log.debug(f"Reading configuration from: {config_file}")
-    with open(config_file) as file:
+    with open(file=config_file, encoding="utf-8", mode="r") as file:
         return yaml.load(file, Loader=yaml.FullLoader)
